@@ -11,14 +11,16 @@
  * @subpackage Example
  */
 
+/* Change this to true if using phpMyAdmin over https */
+$secure_cookie = false;
 /* Need to have cookie visible from parent directory */
-session_set_cookie_params(0, '/', '', false);
+session_set_cookie_params(0, '/', '', $secure_cookie, true);
 /* Create signon session */
 $session_name = 'SignonSession';
 session_name($session_name);
 // Uncomment and change the following line to match your $cfg['SessionSavePath']
 //session_save_path('/foobar');
-session_start();
+@session_start();
 
 /* Was data posted? */
 if (isset($_POST['user'])) {
@@ -31,7 +33,7 @@ if (isset($_POST['user'])) {
     $_SESSION['PMA_single_signon_cfgupdate'] = array('verbose' => 'Signon test');
     $id = session_id();
     /* Close that session */
-    session_write_close();
+    @session_write_close();
     /* Redirect to phpMyAdmin (should use absolute URL here!) */
     header('Location: ../index.php');
 } else {
