@@ -402,11 +402,7 @@ RTE.COMMON = {
              *          the AJAX message shown to the user
              */
             var $msg = PMA_ajaxShowMessage(PMA_messages.strProcessingRequest);
-            var params = {
-                'is_js_confirmed': 1,
-                'ajax_request': true,
-                'token': PMA_commonParams.get('token')
-            };
+            var params = getJSConfirmCommonParam(this, $this.getPostData());
             $.post(url, params, function (data) {
                 if (data.success === true) {
                     /**
@@ -481,11 +477,7 @@ RTE.COMMON = {
                  * @var $curr_row Object containing reference to the current row
                  */
                 var $curr_row = $anchor.parents('tr');
-                var params = {
-                    'is_js_confirmed': 1,
-                    'ajax_request': true,
-                    'token': PMA_commonParams.get('token')
-                };
+                var params = getJSConfirmCommonParam(this, $anchor.getPostData());
                 $.post($anchor.attr('href'), params, function (data) {
                     returnCount++;
                     if (data.success === true) {
