@@ -5,17 +5,14 @@
  *
  * @package PhpMyAdmin
  */
+use PMA\libraries\URL;
+
 if (! defined('PHPMYADMIN')) {
     exit;
 }
 
-/**
- * Gets some core libraries
- */
-require_once './libraries/bookmark.lib.php';
-
 // Check parameters
-PMA_Util::checkParameters(array('db', 'table'));
+PMA\libraries\Util::checkParameters(array('db', 'table'));
 
 $db_is_system_schema = $GLOBALS['dbi']->isSystemSchema($db);
 
@@ -23,7 +20,7 @@ $db_is_system_schema = $GLOBALS['dbi']->isSystemSchema($db);
  * Set parameters for links
  * @deprecated
  */
-$url_query = PMA_URL_getCommon(array('db' => $db, 'table' => $table));
+$url_query = URL::getCommon(array('db' => $db, 'table' => $table));
 
 /**
  * Set parameters for links
@@ -35,15 +32,15 @@ $url_params['table'] = $table;
 /**
  * Defines the urls to return to in case of error in a sql statement
  */
-$err_url_0 = PMA_Util::getScriptNameForOption(
+$err_url_0 = PMA\libraries\Util::getScriptNameForOption(
     $GLOBALS['cfg']['DefaultTabDatabase'], 'database'
 )
-    . PMA_URL_getCommon(array('db' => $db));
+    . URL::getCommon(array('db' => $db));
 
-$err_url = PMA_Util::getScriptNameForOption(
+$err_url = PMA\libraries\Util::getScriptNameForOption(
     $GLOBALS['cfg']['DefaultTabTable'], 'table'
 )
-    . PMA_URL_getCommon($url_params);
+    . URL::getCommon($url_params);
 
 
 /**
@@ -51,5 +48,5 @@ $err_url = PMA_Util::getScriptNameForOption(
  * Skip test if we are exporting as we can't tell whether a table name is an alias (which would fail the test).
  */
 if (basename($_SERVER['PHP_SELF']) != 'tbl_export.php') {
-    require_once './libraries/db_table_exists.lib.php';
+    require_once './libraries/db_table_exists.inc.php';
 }
